is_ps_truncated() returns TRUE if x is a ps_trunc
object or a psw object derived from truncated propensity scores.
Use is_unit_truncated() to find out which observations were modified.
is_ps_truncated() returns TRUE if x is a ps_trunc
object or a psw object derived from truncated propensity scores.
Use is_unit_truncated() to find out which observations were modified.