is_unit_truncated() returns a logical vector indicating which
observations had their propensity scores modified by truncation. Use
is_ps_truncated() to test whether an object has been truncated at all.
Arguments
- x
A
ps_truncobject created byps_trunc().
Value
A logical vector the same length as x (or number of rows for
matrix input). TRUE marks observations whose values were winsorized.